@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQMENUDATA_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QMenuData class
-// For Qt3, no changes are needed
-
 #include <ntqmenudata.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QMenuData class
-// For Qt4, some changes are needed
-
-#include <tqt4/Qt/ntqmenudata.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQMENUDATA_H */
